@@ -85,6 +85,7 @@ static void         ev_sidebar_thumbnails_set_document     (EvSidebarPage
 static const gchar* ev_sidebar_thumbnails_get_label        (EvSidebarPage       *sidebar_page);
 static void         thumbnail_job_completed_callback       (EvJobThumbnail      *job,
 							    EvSidebarThumbnails *sidebar_thumbnails);
+static void         adjustment_changed_cb                  (EvSidebarThumbnails *sidebar_thumbnails);
 
 G_DEFINE_TYPE_EXTENDED (EvSidebarThumbnails, 
                         ev_sidebar_thumbnails, 
@@ -124,8 +125,7 @@ ev_sidebar_thumbnails_get_property (GObject    *object,
 {
 	EvSidebarThumbnails *sidebar = EV_SIDEBAR_THUMBNAILS (object);
 
-	switch (prop_id)
-	{
+	switch (prop_id) {
 	case PROP_WIDGET:
 		if (sidebar->priv->tree_view)
 			g_value_set_object (value, sidebar->priv->tree_view);
@@ -138,17 +138,32 @@ ev_sidebar_thumbnails_get_property (GObject    *object,
 	}
 }
 
+static void
+ev_sidebar_thumbnails_map (GtkWidget *widget)
+{
+	EvSidebarThumbnails *sidebar;
+
+	sidebar = EV_SIDEBAR_THUMBNAILS (widget);
+
+	GTK_WIDGET_CLASS (ev_sidebar_thumbnails_parent_class)->map (widget);
+	
+	adjustment_changed_cb (sidebar);
+}
+
 static void
 ev_sidebar_thumbnails_class_init (EvSidebarThumbnailsClass *ev_sidebar_thumbnails_class)
 {
 	GObjectClass *g_object_class;
 	GtkObjectClass *gtk_object_class;
+	GtkWidgetClass *widget_class;
 
 	g_object_class = G_OBJECT_CLASS (ev_sidebar_thumbnails_class);
 	gtk_object_class = GTK_OBJECT_CLASS (ev_sidebar_thumbnails_class);
+	widget_class = GTK_WIDGET_CLASS (ev_sidebar_thumbnails_class);
 
 	g_object_class->dispose = ev_sidebar_thumbnails_dispose;
 	g_object_class->get_property = ev_sidebar_thumbnails_get_property;
+	widget_class->map = ev_sidebar_thumbnails_map;
 
 	g_object_class_override_property (g_object_class,
 					  PROP_WIDGET,
@@ -290,6 +305,10 @@ adjustment_changed_cb (EvSidebarThumbnails *sidebar_thumbnails)
 	gint wy1;
 	gint wy2;
 
+	/* Widget is not currently visible */
+	if (!GTK_WIDGET_MAPPED (sidebar_thumbnails))
+		return;
+	
 	if (priv->tree_view) {
 		if (! GTK_WIDGET_REALIZED (priv->tree_view))
 			return;
@@ -377,9 +396,9 @@ ev_sidebar_thumbnails_set_loading_icon (EvSidebarThumbnails *sidebar_thumbnails)
 	}
 
 }
+
 void
 ev_sidebar_thumbnails_refresh (EvSidebarThumbnails *sidebar_thumbnails,
-
 			       int                  rotation)
 {
 	sidebar_thumbnails->priv->rotation = rotation;
@@ -414,7 +433,7 @@ ev_sidebar_tree_selection_changed (GtkTreeSelection *selection,
 	page = gtk_tree_path_get_indices (path)[0];
 	gtk_tree_path_free (path);
 
-	ev_page_cache_set_current_page (priv->page_cache, page);
+	ev_page_cache_set_current_page_history (priv->page_cache, page);
 }
 
 static void
@@ -439,7 +458,7 @@ ev_sidebar_icon_selection_changed (GtkIconView         *icon_view,
 	gtk_tree_path_free (path);
 	g_list_free (selected);
 
-	ev_page_cache_set_current_page (priv->page_cache, page);
+	ev_page_cache_set_current_page_history (priv->page_cache, page);
 }
 
 static void
@@ -544,7 +563,17 @@ page_changed_cb (EvPageCache         *page_cache,
 		gtk_tree_view_set_cursor (tree_view, path, NULL, FALSE);
 		gtk_tree_view_scroll_to_cell (tree_view, path, NULL, FALSE, 0.0, 0.0);
 	} else if (sidebar->priv->icon_view) {
+
+		g_signal_handlers_block_by_func
+			(sidebar->priv->icon_view,
+			 G_CALLBACK (ev_sidebar_icon_selection_changed), sidebar);
+
 		gtk_icon_view_select_path (GTK_ICON_VIEW (sidebar->priv->icon_view), path);
+
+		g_signal_handlers_unblock_by_func
+			(sidebar->priv->icon_view,
+			 G_CALLBACK (ev_sidebar_icon_selection_changed), sidebar);
+
 		gtk_icon_view_set_cursor (GTK_ICON_VIEW (sidebar->priv->icon_view), path, NULL, FALSE);
 	}
 
@@ -596,6 +625,8 @@ ev_sidebar_thumbnails_set_document (EvSidebarPage	*sidebar_page,
 		if (! priv->icon_view) {
 			ev_sidebar_init_icon_view (sidebar_thumbnails);
 			g_object_notify (G_OBJECT (sidebar_thumbnails), "main_widget");
+		} else {
+			gtk_widget_queue_resize (priv->icon_view);
 		}
 	} else {
 		if (priv->icon_view) {
